==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetJobPrivateEndpointPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property jobAgentName The name of the job agent.
 * @property privateEndpointName The name of the private endpoint to get.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serverName The name of the server.
 */
public data class GetJobPrivateEndpointPlainArgs(
    public val jobAgentName: String,
    public val privateEndpointName: String,
    public val resourceGroupName: String,
    public val serverName: String,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs =
        com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs.builder()
            .jobAgentName(jobAgentName.let({ args0 -> args0 }))
            .privateEndpointName(privateEndpointName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serverName(serverName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetJobPrivateEndpointPlainArgs].
 */
@PulumiTagMarker
public class GetJobPrivateEndpointPlainArgsBuilder internal constructor() {
    private var jobAgentName: String? = null

    private var privateEndpointName: String? = null

    private var resourceGroupName: String? = null

    private var serverName: String? = null

    /**
     * @param value The name of the job agent.
     */
    @JvmName("wexidhjrkkgissrq")
    public suspend fun jobAgentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.jobAgentName = mapped
    }

    /**
     * @param value The name of the private endpoint to get.
     */
    @JvmName("icxadffkyctoboay")
    public suspend fun privateEndpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateEndpointName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("ekxlbgslmomubcfa")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("erbsppccnhvkpxom")
    public suspend fun serverName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serverName = mapped
    }

    internal fun build(): GetJobPrivateEndpointPlainArgs = GetJobPrivateEndpointPlainArgs(
        jobAgentName = jobAgentName ?: throw PulumiNullFieldException("jobAgentName"),
        privateEndpointName = privateEndpointName ?: throw PulumiNullFieldException("privateEndpointName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serverName = serverName ?: throw PulumiNullFieldException("serverName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/GetJobPrivateEndpointPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property jobAgentName The name of the job agent.
 * @property privateEndpointName The name of the private endpoint to get.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serverName The name of the server.
 */
public data class GetJobPrivateEndpointPlainArgs(
    public val jobAgentName: String,
    public val privateEndpointName: String,
    public val resourceGroupName: String,
    public val serverName: String,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs =
        com.pulumi.azurenative.sql.inputs.GetJobPrivateEndpointPlainArgs.builder()
            .jobAgentName(jobAgentName.let({ args0 -> args0 }))
            .privateEndpointName(privateEndpointName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serverName(serverName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetJobPrivateEndpointPlainArgs].
 */
@PulumiTagMarker
public class GetJobPrivateEndpointPlainArgsBuilder internal constructor() {
    private var jobAgentName: String? = null

    private var privateEndpointName: String? = null

    private var resourceGroupName: String? = null

    private var serverName: String? = null

    /**
     * @param value The name of the job agent.
     */
    @JvmName("jecwrnarliorvixx")
    public suspend fun jobAgentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.jobAgentName = mapped
    }

    /**
     * @param value The name of the private endpoint to get.
     */
    @JvmName("iavmatnwkerdukql")
    public suspend fun privateEndpointName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.privateEndpointName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("drqowwbrxilbrxcc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("kbpcssrjlycmmiyt")
    public suspend fun serverName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serverName = mapped
    }

    internal fun build(): GetJobPrivateEndpointPlainArgs = GetJobPrivateEndpointPlainArgs(
        jobAgentName = jobAgentName ?: throw PulumiNullFieldException("jobAgentName"),
        privateEndpointName = privateEndpointName ?: throw PulumiNullFieldException("privateEndpointName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serverName = serverName ?: throw PulumiNullFieldException("serverName"),
    )
}
